@@ -368,9 +368,9 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 	
 	
 	if (args && strlen (args) > 0)
-		cmd = g_strconcat ("\"",target, "\" ", args, NULL);
+		cmd = g_strconcat (target, " ", args, NULL);
 	else
-		cmd = g_strconcat ("\"", target, "\"", NULL);
+		cmd = g_strdup (target);
 
 	if (anjuta_preferences_get_int (prefs , PREF_USE_SB))
 	{
@@ -422,7 +422,7 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 				
 			}
 
-			ianjuta_terminal_execute_command (term, dir, cmd, NULL);
+			ianjuta_terminal_execute_command (term, dir, cmd, NULL, NULL);
 		}
 		else
 		{
