@@ -642,9 +642,8 @@ on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 			}
 			name = atp_remove_mnemonic (command);
 			g_free (command);
-			command = g_build_filename (g_get_home_dir(),
-										LOCAL_ANJUTA_SCRIPT_DIRECTORY,
-										name, NULL);
+
+			command = anjuta_util_get_user_data_file_path ("scripts/", name, NULL);
 			g_free (name);
 
 			/* Find a new file name */
@@ -781,10 +780,12 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 		{
 			IAnjutaDocumentManager *docman;
 			IAnjutaDocument *doc;
-			gchar *uri;
+			GFile* file;
 
 			/* Check that default script directory exist */
-			data = g_build_filename (g_get_home_dir(), LOCAL_ANJUTA_SCRIPT_DIRECTORY, NULL);
+			data = anjuta_util_get_user_data_file_path ("scripts/", NULL);
+
+			// TODO: Replace with g_mkdir_with_parents
 			make_directory (data);
 			g_free (data);
 
@@ -818,25 +819,25 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 				return;
 			}
 
-			uri = gnome_vfs_get_uri_from_local_path(data);
+			file = g_file_new_for_path (data);
 			g_free (data);
 			doc =
-				ianjuta_document_manager_find_document_with_uri 
-							   (docman, uri, NULL);
+				ianjuta_document_manager_find_document_with_file 
+							   (docman, file, NULL);
 			if (doc == NULL)
 			{
 				IAnjutaFileLoader* loader;
 
 				/* Not found, load file */
 				loader = IANJUTA_FILE_LOADER (anjuta_shell_get_interface (ANJUTA_PLUGIN (this->parent->plugin)->shell, IAnjutaFileLoader, NULL));
-				ianjuta_file_loader_load (loader, uri, FALSE, NULL);
+				ianjuta_file_loader_load (loader, file, FALSE, NULL);
 			}
 			else
 			{
 				/* Set as current */
 				ianjuta_document_manager_set_current_document (docman, doc, NULL);
 			}
-			g_free (uri);
+			g_object_unref (file);
 		}
 	}
 	
