@@ -1,5 +1,5 @@
 /*
-*   $Id: options.c 2877 2007-03-21 16:39:19Z naba $
+*   $Id: options.c 3079 2007-08-30 22:38:54Z jhs $
 *
 *   Copyright (c) 1996-2003, Darren Hiebert
 *
@@ -291,7 +291,7 @@ static const char* const License2 =
 "\n"
 "You should have received a copy of the GNU General Public License\n"
 "along with this program; if not, write to the Free Software\n"
-"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.\n";
+"Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
 
 /*  Contains a set of strings describing the set of "features" compiled into
  *  the code.
